"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthService = void 0;
const common_1 = require("@nestjs/common");
const jwt_1 = require("@nestjs/jwt");
const typeorm_1 = require("@nestjs/typeorm");
const typeorm_2 = require("typeorm");
const user_entity_1 = require("../users/entities/user.entity");
const argon2 = require("argon2");
let AuthService = exports.AuthService = class AuthService {
    constructor(userRepository, jwtService) {
        this.userRepository = userRepository;
        this.jwtService = jwtService;
    }
    async findByDocument(document) {
        return await this.userRepository.findOneBy({ document });
    }
    ;
    async findByEmail(email) {
        return await this.userRepository.findOneBy({ email });
    }
    generateCode() {
        return Math.floor(Math.random() * 9999);
    }
    hiddenMail(email) {
        const hiddenCharacters = 3;
        return email.replace(/[a-z0-9\-_.]+@/ig, (c) => c.substr(0, hiddenCharacters) + c.split('').slice(hiddenCharacters, -1).map(v => '*').join('') + '@');
    }
    async register(userObject) {
        const exists = await this.findByDocument(userObject.document);
        if (exists)
            throw new common_1.NotFoundException('Ya existe un usuario con el documento ingresado');
        const { password } = userObject;
        const plainToHash = await argon2.hash(password, { type: argon2.argon2id });
        userObject = Object.assign(Object.assign({}, userObject), { password: plainToHash });
        const data = this.userRepository.create(userObject);
        await this.userRepository.save(data);
        return { message: 'Usuario registrado exitosamente' };
    }
    async login(userObject) {
        const { email, password } = userObject;
        const findUser = await this.findByEmail(email);
        if (!findUser)
            throw new common_1.NotFoundException('No existe un usuario con ese email');
        const checkPassword = await argon2.verify(findUser.password, password);
        if (!checkPassword)
            throw new common_1.HttpException('Contraseña incorrecta', 403);
        if (!findUser.is_active) {
            throw new common_1.NotFoundException('El usuario se encuentra inactivo');
        }
        const payload = { id: findUser.id, name: findUser.name, avatar: findUser.avatar };
        const token = this.jwtService.sign(payload);
        const data = {
            token
        };
        return data;
    }
    async recoverPass(userObject) {
        const { email } = userObject;
        const findUser = await this.findByEmail(email);
        if (!findUser)
            throw new common_1.NotFoundException('No existe un usuario con ese email');
        findUser.password_recovery_code = this.generateCode().toString();
        this.userRepository.save(findUser);
        this.sendEmailLink(findUser.email, findUser.name, findUser.password_recovery_code);
        const hiddenMail = this.hiddenMail(findUser.email);
        return { message: `Por favor ingresa el código de confirmación enviado a <b>${hiddenMail}</b>` };
    }
    async sendEmailLink(email, name, password_recovery_code) {
    }
    async validateCode(validateCode) {
        const { email, code } = validateCode;
        const findUser = await this.findByEmail(email);
        if (!findUser)
            throw new common_1.NotFoundException('No existe un usuario con ese email');
        if (!findUser.password_recovery_code)
            throw new common_1.NotFoundException('El código ya fue validado');
        if (code !== findUser.password_recovery_code)
            throw new common_1.NotFoundException('El código digitado no es el correcto');
        return { message: 'Los códigos coinciden' };
    }
    async restorePass(restorePass) {
        const { email, newPassword, passwordConfirmation } = restorePass;
        const findUser = await this.findByEmail(email);
        if (!findUser)
            throw new common_1.NotFoundException('No existe un usuario con ese email');
        if (newPassword !== passwordConfirmation)
            throw new common_1.NotFoundException('Las contraseñas no coinciden');
        const plainToHash = await argon2.hash(newPassword, { type: argon2.argon2id });
        findUser.password = plainToHash;
        findUser.password_recovery_code = null;
        await this.userRepository.save(findUser);
        return { message: 'Su contraseña se ha cambiado exitosamente, ahora puede iniciar sesión' };
    }
};
exports.AuthService = AuthService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(user_entity_1.User)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        jwt_1.JwtService])
], AuthService);
//# sourceMappingURL=auth.service.js.map