"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InscriptionsService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const inscription_entity_1 = require("./entities/inscription.entity");
const typeorm_2 = require("typeorm");
const page_dto_1 = require("../dtos-globals/page.dto");
const page_meta_dto_1 = require("../dtos-globals/page-meta.dto");
const companies_entity_1 = require("../entities-globals/companies.entity");
const managers_entity_1 = require("../entities-globals/managers.entity");
const memberships_entity_1 = require("../entities-globals/memberships.entity");
const participants_entity_1 = require("../entities-globals/participants.entity");
const participants_for_inscription_entity_1 = require("../entities-globals/participants_for_inscription.entity");
const membership_ranks_dates_entity_1 = require("../entities-globals/membership_ranks_dates.entity");
const values_for_ranks_entity_1 = require("../entities-globals/values_for_ranks.entity");
const nest_sendgrid_1 = require("@anchan828/nest-sendgrid");
const ExcelJS = require("exceljs");
const fs = require("fs");
const path = require("path");
const date_fns_1 = require("date-fns");
const payment__for_inscription_entity_1 = require("../entities-globals/payment_ for_inscription.entity");
const crypto = require("crypto");
const discounts_codes_entity_1 = require("../entities-globals/discounts_codes.entity");
let InscriptionsService = exports.InscriptionsService = class InscriptionsService {
    constructor(repositoryInscription, repositoryCompany, repositoryManager, repositoryMembership, repositoryParticipant, repositoryParticipantForInscription, repositoryMemberShipRanksDates, repositoryValuesForRanks, repositoryPaymentForInscription, repositoryDiscountCode, sendGrid) {
        this.repositoryInscription = repositoryInscription;
        this.repositoryCompany = repositoryCompany;
        this.repositoryManager = repositoryManager;
        this.repositoryMembership = repositoryMembership;
        this.repositoryParticipant = repositoryParticipant;
        this.repositoryParticipantForInscription = repositoryParticipantForInscription;
        this.repositoryMemberShipRanksDates = repositoryMemberShipRanksDates;
        this.repositoryValuesForRanks = repositoryValuesForRanks;
        this.repositoryPaymentForInscription = repositoryPaymentForInscription;
        this.repositoryDiscountCode = repositoryDiscountCode;
        this.sendGrid = sendGrid;
    }
    async findAll(pageOptionsDto) {
        const queryBuilder = this.repositoryInscription.createQueryBuilder("inscriptions")
            .leftJoinAndSelect("inscriptions.company", "company")
            .leftJoinAndSelect("inscriptions.manager", "manager")
            .leftJoinAndSelect("inscriptions.membership", "membership")
            .select(['inscriptions', 'company.name', 'manager.name', 'membership.name'])
            .orderBy("inscriptions.id", pageOptionsDto.order)
            .skip(pageOptionsDto.skip)
            .take(pageOptionsDto.take);
        const { company, manager, way_to_pay, membership_id, state_transaction, created, term } = pageOptionsDto;
        if (term) {
            queryBuilder.orWhere('company.name LIKE :nameCompany', { nameCompany: `%${term}%` });
            queryBuilder.orWhere('manager.name LIKE :nameManager', { nameManager: `%${term}%` });
            queryBuilder.orWhere('inscriptions.way_to_pay LIKE :way_to_pay', { way_to_pay: `%${term}%` });
            queryBuilder.orWhere('inscriptions.membership_id LIKE :membership_id', { membership_id: `%${term}%` });
            queryBuilder.orWhere('inscriptions.state_transaction LIKE :state_transaction', { state_transaction: `%${term}%` });
            queryBuilder.orWhere('inscriptions.created LIKE :created', { created: `%${term}%` });
        }
        if (company) {
            queryBuilder.andWhere('company.name LIKE :nameCompany', { nameCompany: `%${company}%` });
        }
        if (manager) {
            queryBuilder.andWhere('manager.name LIKE :nameManager', { nameManager: `%${manager}%` });
        }
        if (way_to_pay) {
            queryBuilder.andWhere('inscriptions.way_to_pay LIKE :way_to_pay', { way_to_pay: `%${way_to_pay}%` });
        }
        if (membership_id) {
            queryBuilder.andWhere('inscriptions.membership_id LIKE :membership_id', { membership_id: `%${membership_id}%` });
        }
        if (state_transaction) {
            queryBuilder.andWhere('inscriptions.state_transaction LIKE :state_transaction', { state_transaction: `%${state_transaction}%` });
        }
        if (created) {
            queryBuilder.andWhere('inscriptions.created LIKE :created', { created: `%${created}%` });
        }
        const itemCount = await queryBuilder.getCount();
        const { entities } = await queryBuilder.getRawAndEntities();
        const pageMetaDto = new page_meta_dto_1.PageMetaDto({ itemCount, pageOptionsDto });
        return new page_dto_1.PageDto(entities, pageMetaDto);
    }
    async findOne(id) {
        const data = await this.repositoryInscription.createQueryBuilder("inscription")
            .leftJoinAndSelect("inscription.company", "company")
            .leftJoinAndSelect("inscription.manager", "manager")
            .leftJoinAndSelect("inscription.membership", "membership")
            .leftJoinAndSelect("inscription.paymentForInscription", "paymentForInscription")
            .select([
            'inscription',
            'company',
            'manager',
            'membership.name',
            'paymentForInscription'
        ])
            .where("inscription.id = :id", { id: id })
            .getOne();
        if (!data)
            throw new common_1.NotFoundException('No existe un dato con el id ' + id);
        const participansForInscription = await this.repositoryParticipantForInscription.createQueryBuilder("participansForInscription")
            .leftJoinAndSelect("participansForInscription.participant", "participant")
            .select(['participansForInscription', 'participant'])
            .where("participansForInscription.inscription_id = :inscriptionId", { inscriptionId: id })
            .getMany();
        const participants = [];
        for (let participantForInscription of participansForInscription) {
            participants.push(participantForInscription.participant);
        }
        data.participants = participants;
        return data;
    }
    async create(dto) {
        const { company_id, manager_id } = dto;
        let companyId = 0;
        if (!company_id) {
            const existsRuc = await this.findDuplicateRuc(dto.company.ruc);
            if (existsRuc)
                throw new common_1.NotFoundException('La identificación RUC ya fue registrada');
            const company = await this.createCompany(dto.company);
            companyId = company.id;
        }
        else {
            companyId = company_id;
        }
        let managerId = 0;
        if (!manager_id) {
            const existsEmail = await this.findDuplicateEmail(dto.manager.email);
            if (existsEmail)
                throw new common_1.NotFoundException('El correo ingresado para el representante ya fue registrado');
            const manager = await this.createManager(dto.manager, companyId);
            managerId = manager.id;
        }
        else {
            managerId = manager_id;
        }
        const data = await this.repositoryInscription.create({
            event_id: 1,
            company_id: companyId,
            manager_id: managerId,
            membership_id: dto.membership_id,
            created: new Date(),
            way_to_pay: dto.way_to_pay,
            about_the_event: dto.about_the_event,
            number_of_participants: dto.number_of_participants,
            unit_value: dto.unit_value,
            discount: dto.discount,
            subtotal: dto.subtotal,
            itbms: dto.itbms,
            total: dto.total
        });
        const inscription = await this.repositoryInscription.save(data);
        const orderNumber = await this.createPayment(inscription.id);
        const participants = await this.createParticipants(dto.participants, inscription.id);
        await this.sendEmailManager(dto.manager, participants, inscription.subtotal, inscription.itbms, inscription.total);
        await this.sendEmailParticipants(participants);
        return {
            message: 'Información registrada exitosamente',
            orderNumber: orderNumber
        };
    }
    async update(id, dto) {
        const data = await this.findOne(id);
        if (!data)
            throw new common_1.NotFoundException({ message: 'No existe la información solicitada' });
        await this.repositoryInscription.update(id, dto);
        return { message: 'Información actualizada exitosamente' };
    }
    async remove(id) {
        await this.findOne(id);
        await this.repositoryInscription.delete(id);
        return { message: 'Información eliminada exitosamente' };
    }
    async validateIdentity(identity) {
        const participant = await this.repositoryParticipant.findOneBy({ identity: identity });
        if (participant)
            return { message: 'Ya existe un participante con la identidad ingresada' };
    }
    async validateEmail(email) {
        const participant = await this.repositoryParticipant.findOneBy({ email: email });
        if (participant)
            return { message: 'Ya existe un participante con el correo ingresado' };
    }
    async findValueParticipant(dto) {
        const { membership_id, number_of_participants } = dto;
        const currentDate = new Date();
        const memberShipRanksDates = this.repositoryMemberShipRanksDates.createQueryBuilder("memberShipRanksDates")
            .where("memberShipRanksDates.membership_id= :membershipId", { membershipId: membership_id })
            .andWhere(":currentDate BETWEEN memberShipRanksDates.initial_date AND memberShipRanksDates.final_date", { currentDate })
            .getOne();
        const memberShipRanksDatesId = (await memberShipRanksDates).id;
        const valueForRanks = this.repositoryValuesForRanks.createQueryBuilder("valuesForRanks")
            .where("valuesForRanks.membership_rank_id= :membershipRankId", { membershipRankId: memberShipRanksDatesId })
            .andWhere(":number_of_participants BETWEEN valuesForRanks.initial_amount AND valuesForRanks.final_amount", { number_of_participants })
            .getOne();
        return (await valueForRanks).value;
    }
    async findMemberships() {
        const data = this.repositoryMembership.createQueryBuilder("memberships")
            .where("memberships.event_id= :eventId", { eventId: 1 })
            .getMany();
        return data;
    }
    async updateVoucher(dto) {
        const { inscriptionId, voucher } = dto;
        const data = await this.repositoryInscription.findOneBy({ id: inscriptionId });
        if (!data)
            throw new common_1.NotFoundException('No existe un dato con el id ' + inscriptionId);
        data.voucher = voucher;
        data.state_transaction = true;
        await this.repositoryInscription.save(data);
        return { message: 'Comprobante cargado exitosamente' };
    }
    async updatePayment(dto) {
        const data = await this.repositoryPaymentForInscription.findOneBy({ CDSC: dto.CDSC });
        if (!data)
            throw new common_1.NotFoundException('No existe un dato con el número de orden ' + dto.CDSC);
        const dataInscription = await this.repositoryInscription.findOneBy({ id: data.inscription_id });
        if (!dataInscription)
            throw new common_1.NotFoundException('No existe un dato con el id ' + data.inscription_id);
        dataInscription.state_transaction = true;
        data.total_paid = dto.TotalPagado;
        data.date = dto.Fecha;
        data.type = dto.Tipo;
        data.oper = dto.Oper;
        data.user = dto.Usuario;
        data.email = dto.Email;
        data.state = dto.Estado;
        data.reason = dto.Razon;
        data.CMTN = dto.CMTN;
        data.CCLW = dto.CCLW;
        await this.repositoryInscription.save(dataInscription);
        await this.repositoryPaymentForInscription.save(data);
    }
    async existCompany(dto) {
        const { ruc } = dto;
        const company = await this.repositoryCompany.findOneBy({ ruc: ruc });
        if (company)
            return company;
    }
    async existManager(dto) {
        const { email } = dto;
        const manager = await this.repositoryManager.findOneBy({ email: email });
        if (manager)
            return manager;
    }
    async hasDiscount(dto) {
        const { email, code } = dto;
        const discountCodeForParticipant = await this.repositoryDiscountCode.createQueryBuilder("discountCode")
            .where("discountCode.email = :email", { email: email })
            .getOne();
        if (!discountCodeForParticipant)
            return {
                status: false,
                message: 'No existe un descuento para el correo ' + email
            };
        if (discountCodeForParticipant.state_code)
            return {
                status: false,
                message: 'El descuento ya fue aplicado para el correo ' + email
            };
        if (discountCodeForParticipant.code !== code)
            return {
                status: false,
                message: 'El código ingresado no tiene descuento para el correo ' + email
            };
        return {
            status: true,
            message: 'Código de descuento cargado para el correo ' + email,
            value: discountCodeForParticipant.value
        };
    }
    async getValueDiscount(dto) {
        const { email } = dto;
        const discountCodeForParticipant = await this.repositoryDiscountCode.createQueryBuilder("discountCode")
            .where("discountCode.email = :email", { email: email })
            .getOne();
        return discountCodeForParticipant.value;
    }
    async createPayment(inscriptionId) {
        const orderNumber = this.generarNumeroOrden();
        const data = await this.repositoryPaymentForInscription.create({
            inscription_id: inscriptionId,
            CDSC: orderNumber
        });
        const created = await this.repositoryPaymentForInscription.save(data);
        return created.CDSC;
    }
    generarNumeroOrden() {
        const timestamp = new Date().getTime();
        const randomBytes = crypto.randomBytes(2);
        const randomString = randomBytes.toString('hex');
        const numeroOrden = `${timestamp}${randomString}`;
        return numeroOrden;
    }
    async createCompany(company) {
        const data = this.repositoryCompany.create(company);
        const created = await this.repositoryCompany.save(data);
        return created;
    }
    async createManager(manager, companyId) {
        manager = Object.assign(Object.assign({}, manager), { company_id: companyId });
        const data = this.repositoryManager.create(manager);
        const created = await this.repositoryManager.save(data);
        return created;
    }
    async findDuplicateRuc(ruc) {
        return await this.repositoryCompany.findOneBy({ ruc });
    }
    async findDuplicateEmail(email) {
        return await this.repositoryManager.findOneBy({ email });
    }
    async createParticipants(participants, inscriptionId) {
        const participantsSaved = [];
        for (let participant of participants) {
            participantsSaved.push(await this.createParticipant(participant, inscriptionId));
        }
        return participantsSaved;
    }
    async createParticipant(participant, inscriptionId) {
        let data = this.repositoryParticipant.create(participant);
        const participan = await this.repositoryParticipant.save(data);
        if (participant.discount_code) {
            const discountCodeForParticipant = await this.repositoryDiscountCode.createQueryBuilder("discountCode")
                .where("discountCode.email = :email", { email: participant.email })
                .getOne();
            discountCodeForParticipant.state_code = true;
            await this.repositoryDiscountCode.save(discountCodeForParticipant);
        }
        this.createParticipantForInscription(participan.id, inscriptionId);
        return participan;
    }
    async createParticipantForInscription(participantId, inscriptionId) {
        let fact = { participant_id: participantId, inscription_id: inscriptionId };
        let data = this.repositoryParticipantForInscription.create(fact);
        await this.repositoryParticipantForInscription.save(data);
    }
    async sendEmailManager(manager, participants, subtotal, itbms, total) {
        const isValidEmail = this.isValidEmail(manager.email);
        if (isValidEmail) {
            let participantsHtml = '';
            participants.forEach(participant => {
                participantsHtml += `<tr><td align="left">${participant.name}</td></tr>`;
            });
            const imageBase64 = await this.imageToBase64('public/images/logo-mktrends.png');
            const emailHtml = `
        <img src="images/logo-mktrends.png" alt='Logo Mk trends'/>
        <p>Hola ${manager.name}, ha realizado exitosamente el registro de participantes para MARKETING TRENDS 2024. A continuación le compartimos el detalle del registro para que pueda utilizar este documento como soporte para el pago del registro.</p>
        <table border="1">
          <thead>
            <tr>
              <th align="left">Nombre</th>
            </tr>
          </thead>
          <tbody>
            ${participantsHtml}
          </tbody>
        </table><br>
        <span>Subtotal: ${subtotal}</span><br>
        <span>ITBMS: ${itbms}</span><br>
        <span>Total a pagar: ${total}</span><br>
        <p>Los pagos pueden realizarse mediante transferencia a nuestra cuenta en BANCO GENERAL a nombre de 4D VISION, INC, Cuenta Corriente # 03-71-01-073385-0. Número fiscal o RUC 192-30-15-17261512 DV46 
        Para transferencias internacionales Banco General, SWIFT BAGEPAPA RUT CH 000000071</p>
        <p><strong>CONDICIONES Y POLITICAS DE INSCRIPCIÓN</strong><br>
        La compra de inscripciones pueden ser transferibles a otros participantes, no se realizarán devoluciones se podrá generar Nota de Crédito del 75% del valor pagado para que sea utilizado en otros eventos.</p>
      `;
            await this.sendGrid.send({
                to: manager.email,
                from: process.env.FROM_EMAIL,
                subject: "MARKETING TRENDS 2024 - REGISTRO EXITOSO",
                html: emailHtml,
                attachments: [
                    {
                        content: imageBase64,
                        filename: 'logo.png',
                        type: 'image/png'
                    },
                ],
            });
        }
    }
    async imageToBase64(filePath) {
        const imageBuffer = await fs.promises.readFile(filePath);
        const base64Image = imageBuffer.toString('base64');
        return base64Image;
    }
    async sendEmailParticipants(participants) {
        for (let participant of participants) {
            await this.sendEmailParticipant(participant);
        }
    }
    async sendEmailParticipant(participant) {
        const isValidEmail = this.isValidEmail(participant.email);
        if (isValidEmail) {
            const emailHtml = `
        <img src="images/logo-mktrends.png" alt='Logo Mk trends'/>
        <p>Hola ${participant.name}, usted ha sido exitosamente registrado para participar en MARKETING TRENDS 2024, al final de este correo aparece su código de inscripción el cual podrá ser presentando para un registro expedito o puede mostrar un documentos de identificación personal y podrá ingresar al evento.</p>
      `;
            const imageLogo = await this.imageToBase64('public/images/logo-mktrends.png');
            const imageQr = await this.imageToBase64('public/images/qr.jpg');
            await this.sendGrid.send({
                to: participant.email,
                from: process.env.FROM_EMAIL,
                subject: "MARKETING TRENDS 2024 - REGISTRO EXITOSO",
                html: emailHtml,
                attachments: [
                    {
                        content: imageLogo,
                        filename: 'logo.png',
                        type: 'image/png'
                    },
                    {
                        content: imageQr,
                        filename: 'qr.jpg',
                        type: 'image/jpeg'
                    }
                ],
            });
        }
    }
    isValidEmail(email) {
        const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return emailRegex.test(email);
    }
    async generateExcelData(filtersDto) {
        const queryBuilder = this.repositoryInscription.createQueryBuilder("inscriptions")
            .leftJoinAndSelect("inscriptions.company", "company")
            .leftJoinAndSelect("inscriptions.manager", "manager")
            .leftJoinAndSelect("inscriptions.membership", "membership")
            .leftJoinAndSelect("inscriptions.participantsForInscription", "participantsForInscription")
            .leftJoinAndSelect("participantsForInscription.participant", "participants")
            .select(['inscriptions', 'company', 'manager', 'membership.name', 'participantsForInscription', 'participants'])
            .orderBy("inscriptions.id", "ASC");
        const { company, manager, way_to_pay, membership_id, state_transaction, created } = filtersDto;
        if (company) {
            queryBuilder.andWhere('company.name LIKE :nameCompany', { nameCompany: `%${company}%` });
        }
        if (manager) {
            queryBuilder.andWhere('manager.name LIKE :nameManager', { nameManager: `%${manager}%` });
        }
        if (way_to_pay) {
            queryBuilder.andWhere('inscriptions.way_to_pay LIKE :way_to_pay', { way_to_pay: `%${way_to_pay}%` });
        }
        if (membership_id) {
            queryBuilder.andWhere('inscriptions.membership_id LIKE :membership_id', { membership_id: `%${membership_id}%` });
        }
        if (state_transaction) {
            queryBuilder.andWhere('inscriptions.state_transaction LIKE :state_transaction', { state_transaction: `%${state_transaction}%` });
        }
        if (created) {
            queryBuilder.andWhere('inscriptions.created LIKE :created', { created: `%${created}%` });
        }
        const { entities } = await queryBuilder.getRawAndEntities();
        const data = [];
        for (let entity of entities) {
            for (let participantsForInscription of entity.participantsForInscription) {
                const fact = {};
                fact['RUC Empresa'] = entity.company.ruc;
                fact['Nombre Comercial Empresa'] = entity.company.name;
                fact['Dirección Empresa'] = entity.company.address_1;
                fact['Teléfono Empresa'] = entity.company.phone;
                fact['Nombre Encargado'] = entity.manager.name;
                fact['Correo Encargado'] = entity.manager.email;
                fact['ID Participante'] = participantsForInscription.participant.identity;
                fact['Nombre Participante'] = participantsForInscription.participant.name + ' ' + participantsForInscription.participant.last_name;
                fact['Correo Participante'] = participantsForInscription.participant.email;
                fact['Forma de Pago'] = entity.way_to_pay;
                fact['Tipo de Inscripción'] = entity.membership.name;
                fact['Valor Inscripción'] = entity.unit_value;
                fact['Total Inscripción'] = entity.total;
                fact['Fecha'] = (0, date_fns_1.format)(entity.created, 'yyyy/MM/dd');
                fact['Estado'] = entity.state_transaction == false ? 'Pendiente' : 'Aprobada';
                data.push(fact);
            }
        }
        return data;
    }
    async generateExcelFile(data) {
        const workbook = new ExcelJS.Workbook();
        const worksheet = workbook.addWorksheet('Sheet 1');
        const headers = Object.keys(data[0]);
        worksheet.addRow(headers);
        const headerRow = worksheet.getRow(1);
        headerRow.eachCell(cell => {
            cell.font = {
                color: { argb: '2EA443' }
            };
        });
        data.forEach(row => {
            const rowData = headers.map(header => row[header]);
            const dataRow = worksheet.addRow(rowData);
            dataRow.eachCell(cell => {
                cell.font = {
                    color: { argb: '616468' }
                };
            });
        });
        const columnHeaders = worksheet.getRow(1);
        columnHeaders.eachCell((cell, colNumber) => {
            const columnHeader = headers[colNumber - 1];
            const headerLength = columnHeader.length;
            const maxLength = Math.max(headerLength, ...data.map(row => String(row[columnHeader]).length));
            worksheet.getColumn(colNumber).width = Math.max(10, maxLength * 1.5);
        });
        const exportDir = path.join(__dirname, '..', 'exports');
        if (!fs.existsSync(exportDir)) {
            fs.mkdirSync(exportDir);
        }
        const filePath = path.join(exportDir, 'exported_data.xlsx');
        await workbook.xlsx.writeFile(filePath);
        return filePath;
    }
    createReadableStream(filePath) {
        const fileStream = fs.createReadStream(filePath);
        return fileStream;
    }
};
exports.InscriptionsService = InscriptionsService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(inscription_entity_1.Inscription)),
    __param(1, (0, typeorm_1.InjectRepository)(companies_entity_1.Company)),
    __param(2, (0, typeorm_1.InjectRepository)(managers_entity_1.Manager)),
    __param(3, (0, typeorm_1.InjectRepository)(memberships_entity_1.Membership)),
    __param(4, (0, typeorm_1.InjectRepository)(participants_entity_1.Participant)),
    __param(5, (0, typeorm_1.InjectRepository)(participants_for_inscription_entity_1.ParticipantsForInscription)),
    __param(6, (0, typeorm_1.InjectRepository)(membership_ranks_dates_entity_1.MembershipRanksDates)),
    __param(7, (0, typeorm_1.InjectRepository)(values_for_ranks_entity_1.ValuesForRanks)),
    __param(8, (0, typeorm_1.InjectRepository)(payment__for_inscription_entity_1.PaymentForInscription)),
    __param(9, (0, typeorm_1.InjectRepository)(discounts_codes_entity_1.DiscountCode)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        typeorm_2.Repository,
        nest_sendgrid_1.SendGridService])
], InscriptionsService);
//# sourceMappingURL=inscriptions.service.js.map