"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsersService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const user_entity_1 = require("./entities/user.entity");
const typeorm_2 = require("typeorm");
const page_dto_1 = require("../dtos-globals/page.dto");
const page_meta_dto_1 = require("../dtos-globals/page-meta.dto");
const argon2 = require("argon2");
let UsersService = exports.UsersService = class UsersService {
    constructor(userRepository) {
        this.userRepository = userRepository;
    }
    async findAll(pageOptionsDto) {
        const queryBuilder = this.userRepository.createQueryBuilder("users")
            .select('users');
        queryBuilder
            .orderBy("users.id", pageOptionsDto.order)
            .skip(pageOptionsDto.skip)
            .take(pageOptionsDto.take)
            .orWhere('users.name LIKE :name', { name: `%${pageOptionsDto.term}%` })
            .orWhere('users.last_name LIKE :last_name', { last_name: `%${pageOptionsDto.term}%` })
            .orWhere('users.email LIKE :email', { email: `%${pageOptionsDto.term}%` })
            .orWhere('users.phone LIKE :phone', { phone: `%${pageOptionsDto.term}%` })
            .orWhere('users.type_document LIKE :type_document', { type_document: `%${pageOptionsDto.term}%` })
            .orWhere('users.document LIKE :document', { document: `%${pageOptionsDto.term}%` });
        const itemCount = await queryBuilder.getCount();
        const { entities } = await queryBuilder.getRawAndEntities();
        const pageMetaDto = new page_meta_dto_1.PageMetaDto({ itemCount, pageOptionsDto });
        return new page_dto_1.PageDto(entities, pageMetaDto);
    }
    async findOne(id) {
        const data = await this.userRepository.findOneBy({ id: id });
        if (!data)
            throw new common_1.NotFoundException('No existe el usuario con el id ' + id);
        return data;
    }
    async findByDocument(document) {
        return await this.userRepository.findOneBy({ document });
    }
    ;
    async findByEmail(email) {
        return await this.userRepository.findOneBy({ email });
    }
    async create(dto) {
        const existsDocument = await this.findByDocument(dto.document);
        if (existsDocument)
            throw new common_1.NotFoundException('Ya existe un usuario con el documento ingresado');
        const existsEmail = await this.findByEmail(dto.email);
        if (existsEmail)
            throw new common_1.NotFoundException('Ya existe un usuario con el correo ingresado');
        const { password } = dto;
        const plainToHash = await argon2.hash(password, { type: argon2.argon2id });
        dto = Object.assign(Object.assign({}, dto), { password: plainToHash });
        const data = this.userRepository.create(dto);
        await this.userRepository.save(data);
        return { message: 'Usuario registrado exitosamente' };
    }
    async update(id, dto) {
        const data = await this.findOne(id);
        if (!data)
            throw new common_1.NotFoundException({ message: 'No existe el usuario solicitado' });
        await this.userRepository.update(id, dto);
        return { message: 'Usuario actualizado exitosamente' };
    }
    async remove(id) {
        await this.findOne(id);
        const count = await this.userRepository.count();
        if (count == 1) {
            throw new common_1.NotFoundException('No se pueden eliminar todos los usuarios');
        }
        await this.userRepository.delete(id);
        return { message: 'Usuario eliminado exitosamente' };
    }
};
exports.UsersService = UsersService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(user_entity_1.User)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], UsersService);
//# sourceMappingURL=users.service.js.map